@@ -80,14 +80,14 @@ def get_feature_from_data(tokenizer, input_text, target=None, maxlen=512, separa
         row_dict['target'] = [0, 0]
         tokenized_input = [tok.tok_begin(tokenizer)] + t_input + [tok.tok_sep(tokenizer)]
         input_id = tokenizer.convert_tokens_to_ids(tokenized_input)
-        ext_tok = []
         if target is not None:
             start, end = target
             ori_start = start = int(start)
             ori_end = end = int(end)
             ori_ans = input_text_list[ori_start:ori_end]
-
-            if mapping_index[t_pos[0]]['pos'] > ori_end:
+            start -= t_pos[0]
+            end -= t_pos[0]
+            if mapping_index[start]['pos'] > ori_end or start < 0 or start > maxlen or end >= maxlen - 2:
                 start = 0
                 end = 0
             else:
@@ -98,11 +98,10 @@ def get_feature_from_data(tokenizer, input_text, target=None, maxlen=512, separa
                             start += length - 1
                         if map_pos < ori_end:
                             end += length - 1
-
-            if ori_ans != tokenized_input[start + 1:end + 1]:
-                if tokenizer.tokenize(" ".join(ori_ans)) != tokenized_input[start + 1:end + 1] and start != end != 0:
-                    print("processed result change", "ORI ANS:", ori_ans, "TOK ANS:",
-                          tokenized_input[start + 1:end + 1], ori_start, ori_end, start, end)
+            if ori_ans != tokenized_input[start + 1:end + 1] and tokenizer.tokenize(
+                    " ".join(ori_ans)) != tokenized_input[start + 1:end + 1] and start != end != 0:
+                start = 0
+                end = 0
             row_dict['target'] = [start + 1, end + 1]  # cls +1
 
         mask_id = [1] * len(input_id)
