@@ -22,6 +22,7 @@ class TestModel(unittest.TestCase):
             for k, v in feature.items():
                 feature[k] = [v, v]
 
+            print(feature)
             # test train
             print(model(feature))
             self.assertTrue(isinstance(model(feature), Tensor))
@@ -75,9 +76,10 @@ class TestModel(unittest.TestCase):
 
         # test eval top k = 2
         top_k_label, top_k_dict = model.predict(input=input, topk=2)
+        print(top_k_label)
         print("test predict with top k 2, ", top_k_label[0][0])
         print("test predict with top k 2, ", top_k_label[0][1])
-        self.assertTrue(len(top_k_label[0]) == 2)
+        self.assertTrue(len(top_k_label) == 2)
 
         # test exceed 512
         for merge_strategy in ['minentropy', 'maxcount', 'maxprob']:
@@ -155,7 +157,7 @@ class TestModel(unittest.TestCase):
         # test exceed 512
         result, model_dict = model.predict(input="T " * 512)
         self.assertTrue(isinstance(result, list))
-        self.assertTrue(len(result) == 0)
+        self.assertTrue(len(result[0][0]) == 0)
 
     def testOnce(self):
         input = "See you next time"
