@@ -5,29 +5,45 @@ from tqdm import tqdm
 
 
 def tok_begin(tokenizer):
-    return tokenizer._cls_token or tokenizer._bos_token or 'cls'
+    if isinstance(tokenizer.cls_token, str):
+        return tokenizer.cls_token
+    elif isinstance(tokenizer.bos_token, str):
+        return tokenizer.bos_token
+    return 'cls'
 
 
 def tok_sep(tokenizer):
-    return tokenizer._sep_token or tokenizer._eos_token or 'sep'
+    if isinstance(tokenizer.sep_token, str):
+        return tokenizer.sep_token
+    elif isinstance(tokenizer.eos_token, str):
+        return tokenizer.eos_token
+    return 'sep'
 
 
 def tok_mask(tokenizer):
-    return tokenizer._mask_token or 'msk'
+    if isinstance(tokenizer.mask_token, str):
+        return tokenizer.mask_token
+    return 'msk'
 
 
 def tok_pad(tokenizer):
-    return tokenizer._pad_token or 'pad'
+    if isinstance(tokenizer.pad_token, str):
+        return tokenizer.pad_token
+    return 'pad'
 
 
 def handle_exceed(tokenizer, seq, maxlen, mode=['remove', 'slide', 'start_slice', 'end_slice']):
     mode = mode[0] if isinstance(mode, list) else mode
-    t_seq = tokenizer.tokenize(seq)
+    seq = seq.replace("[MASK]", tok_mask(tokenizer)).replace("[SEP]", tok_sep(tokenizer)).replace("[CLS]",
+                                                                                                  tok_begin(tokenizer))
+    sep_split = seq.split(tok_sep(tokenizer))
+    ext_seq = [tok_sep(tokenizer)] + tokenizer.tokenize(sep_split[1]) if len(sep_split) > 1 else []
+    t_seq = tokenizer.tokenize(sep_split[0])
     if mode == 'remove':
         ret_list = [t_seq] if len(t_seq) <= maxlen else []
         return ret_list, [[0, 0]]
     if mode == 'slide':
-        return nlp2.sliding_windows(t_seq, maxlen)
+        return nlp2.sliding_windows(t_seq, maxlen - len(ext_seq), append_seq=ext_seq)
     if mode == 'start_slice':
         return [t_seq[:maxlen]], [[0, maxlen]]
     if mode == 'end_slice':
@@ -41,7 +57,7 @@ def get_topP_unk_token(tokenizer, file_paths: list, topP: float):
             for tok in nlp2.split_sentence_to_array(input_sent):
                 if tokenizer._unk_token in tokenizer.tokenize(tok):
                     unk_count_dict[tok] = unk_count_dict.get(tok, 0) + 1
-    top_range = int(len(unk_count_dict) * (topP / 100))
+    top_range = int((len(unk_count_dict) + 1) * topP * 100)
     return list(unk_count_dict.keys())[:top_range]
 
 
